# Changelog

## [stormi-v0.2.5](https://github.com/pinellolab/stormi/compare/stormi-v0.2.4...stormi-v0.2.5) (2025-04-07)

### Bug Fixes

* **pyproject:** add dvc to docs deps ([08396f3](https://github.com/pinellolab/stormi/commit/08396f396e899431ddd163ed32f279ca2052f0c3))
